package com.zehong.system.service.impl;

import java.util.List;
import com.zehong.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.zehong.system.mapper.TLpgSafeCheckRecordMapper;
import com.zehong.system.domain.TLpgSafeCheckRecord;
import com.zehong.system.service.ITLpgSafeCheckRecordService;

/**
 * 液化石油安检记录Service业务层处理
 * 
 * @author zehong
 * @date 2024-07-22
 */
@Service
public class TLpgSafeCheckRecordServiceImpl implements ITLpgSafeCheckRecordService 
{
    @Autowired
    private TLpgSafeCheckRecordMapper tLpgSafeCheckRecordMapper;

    /**
     * 查询液化石油安检记录
     * 
     * @param safeCheckId 液化石油安检记录ID
     * @return 液化石油安检记录
     */
    @Override
    public TLpgSafeCheckRecord selectTLpgSafeCheckRecordById(Long safeCheckId)
    {
        return tLpgSafeCheckRecordMapper.selectTLpgSafeCheckRecordById(safeCheckId);
    }

    /**
     * 查询液化石油安检记录列表
     * 
     * @param tLpgSafeCheckRecord 液化石油安检记录
     * @return 液化石油安检记录
     */
    @Override
    public List<TLpgSafeCheckRecord> selectTLpgSafeCheckRecordList(TLpgSafeCheckRecord tLpgSafeCheckRecord)
    {
        return tLpgSafeCheckRecordMapper.selectTLpgSafeCheckRecordList(tLpgSafeCheckRecord);
    }

    /**
     * 新增液化石油安检记录
     * 
     * @param tLpgSafeCheckRecord 液化石油安检记录
     * @return 结果
     */
    @Override
    public int insertTLpgSafeCheckRecord(TLpgSafeCheckRecord tLpgSafeCheckRecord)
    {
        tLpgSafeCheckRecord.setCreateTime(DateUtils.getNowDate());
        return tLpgSafeCheckRecordMapper.insertTLpgSafeCheckRecord(tLpgSafeCheckRecord);
    }

    /**
     * 修改液化石油安检记录
     * 
     * @param tLpgSafeCheckRecord 液化石油安检记录
     * @return 结果
     */
    @Override
    public int updateTLpgSafeCheckRecord(TLpgSafeCheckRecord tLpgSafeCheckRecord)
    {
        tLpgSafeCheckRecord.setUpdateTime(DateUtils.getNowDate());
        return tLpgSafeCheckRecordMapper.updateTLpgSafeCheckRecord(tLpgSafeCheckRecord);
    }

    /**
     * 批量删除液化石油安检记录
     * 
     * @param safeCheckIds 需要删除的液化石油安检记录ID
     * @return 结果
     */
    @Override
    public int deleteTLpgSafeCheckRecordByIds(Long[] safeCheckIds)
    {
        return tLpgSafeCheckRecordMapper.deleteTLpgSafeCheckRecordByIds(safeCheckIds);
    }

    /**
     * 删除液化石油安检记录信息
     * 
     * @param safeCheckId 液化石油安检记录ID
     * @return 结果
     */
    @Override
    public int deleteTLpgSafeCheckRecordById(Long safeCheckId)
    {
        return tLpgSafeCheckRecordMapper.deleteTLpgSafeCheckRecordById(safeCheckId);
    }
}
